Learn R Programming

spaMM (version 4.7.0)

control.HLfit: Control parameters of the HLfit fitting algorithm

Description

A list of parameters controlling the HLfit fitting algorithm (called by all fitting functions in spaMM). It can mostly be ignored in routine use.

Usage

# (., control.HLfit=list(...))

Arguments

Details

Possible controls are:

  • algebra, sparse_precision: see algebra.

  • max.iter: the number of iterations of the iterative algorithm for joint estimation of dispersion parameters and of coefficients of the linear predictor. Defaults to 200. This is typically much more than necessary, unless there is little information to separately estimate \(\lambda\) and \(\phi\) parameters.

  • conv.threshold and spaMM_tol: spaMM_tol is a list of tolerance values, with elements Xtol_rel and Xtol_abs that define thresholds for relative and absolute changes in parameter values in iterative algorithms (used in tests of the form “d(param)< Xtol_rel * param + Xtol_abs”, so that Xtol_abs is operative only for small parameter values). conv.threshold is the older way to control Xtol_rel. Default values are given by spaMM.getOption("spaMM_tol").

  • min_phi: NULL or a positive numeric value, being the minimum value of the residual dispersion parameter \(\phi\), when “inner-estimated” (inner-vs-outer for this concept). Values approaching zero may induce numerical errors in various steps of the fitting algorithm. For Gaussian- or Gamma-family models, \(\phi\) values as low as 1e-12 are usually not a source of concern; but setting min_phi to higher values has been needed at least for fits with an experimental implementation of the tweedie family.

  • break_conv_logL: a boolean specifying whether the iterative algorithm should terminate when log-likelihood appears to have converged (roughly, when its relative variation over on iteration is lower than 1e-8). Default is FALSE (convergence is then assessed on the parameter estimates rather than on log-likelihood).

  • iter.mean.dispFix: the number of iterations of the iterative algorithm for coefficients of the linear predictor, if no dispersion parameters are estimated by the iterative algorithm. Defaults to 200 except for Gamma(log)-family models.

  • iter.mean.dispVar: the number of iterations of the iterative algorithm for coefficients of the linear predictor, if some dispersion parameter(s) is estimated by the iterative algorithm. Defaults to 50 except for Gamma(log)-family models.

resid.family was a previously documented control (before version 2.6.40), and might still operate as previously documented, but should not be used in new code.