how: Extract information about how an object was obtained

howR Documentation

Extract information about how an object was obtained

Description

how is defined as a generic with currently only one non-default method, for objects of class HLfit. This method provide information about how such a fit was obtained.

Usage

how(object, ...)
## S3 method for class 'HLfit'
how(object, devel=FALSE, verbose=TRUE, format=print, ...)
## S3 method for class 'HLfitlist'
how(object, devel=FALSE, verbose=TRUE, format=print, ...)

Arguments

object

Any R object.

devel

Boolean; Whether to provide additional cryptic information. For development purposes, not further documented.

verbose

Boolean; Whether to print information about the input object.

format

wrapper for printing format. E.g., cat(cli::col_yellow(s),"\n") could be used instead of the default.

...

Other arguments that may be needed by some method.

Value

A list, returned invisibly, whose elements are not further described here, some being slightly cryptic or subject to future changes. However, how(.)$fit_time is a clean way of getting the fit time, and element algebra stores a value that can be used as the algebra element in the control.HLfit argument of the fitting functions. If verbose is TRUE, the function prints a message presenting some of the information stored in the returned list.

See Also

algebra

Examples

foo <- HLfit(y~x, data=data.frame(x=runif(3), y=runif(3)), method="ML", ranFix=list(phi=1))
how(foo)

spaMM documentation built on Sept. 10, 2026, 1:07 a.m.