Learn R Programming

spaMM (version 4.7.0)

summary.HLfit: Summary and print methods for fit and test results.

Description

Summary and print methods for results from HLfit or related functions. summary may also be used as an extractor (see e.g. beta_table).

Usage

# S3 method for HLfit
summary(object, details=FALSE, max.print=100L, verbose=TRUE, ...)
# S3 method for HLfitlist
summary(object, ...)
# S3 method for fixedLRT
summary(object, verbose=TRUE, ...)
# S3 method for HLfit
print(x,...)
# S3 method for HLfitlist
print(x,...)
# S3 method for fixedLRT
print(x,...)

Value

The return value is a list whose elements may be subject to changes, but two of them can be considered stable, and are thus part of the API: the beta_table and lambda_table which are the displayed tables for the coefficients of fixed effects and random-effect variances.

Arguments

object

An object of class HLfit, as returned by the fitting functions in spaMM.

x

The return object of HLfit or related functions.

verbose

For summary.HLfit, whether to print the screen output that is the primary purpose of summary. verbose=FALSE may be convenient when summary is used as an extractor. For summary.fixedLRT, whether to print the model fits or not.

max.print

Controls options("max.print") locally.

details

A list or vector, with elements controlling whether to print some obscure details. Handled non-default elements are:

  • ranCoefs=TRUE will print details about random-coefficients terms (see Details);

  • p_value="Wald" will print a p-value for the t-value of each fixed-effect coefficient, assuming a gaussian distribution of the test statistic (but, beyond the generally questionable nature of p-value tables, see e.g. LRT and fixedLRT for alternative testing approaches);

  • p_value=TRUE is similar to p_value="Wald" but instead uses Student's t test;

  • full.form=numeric value controls abbreviation of the display of model formulas if the number of output lines of a full display would exceed the given value. This may be particularly useful for multivariate-response fits ( See Details for the way formulas are abbreviated). full.form=TRUE is interpreted as full.form=Inf, and FALSE is interpreted as 0 (so that multiline submodel formulas are always abbreviated). Both the default (no specified value) and an explicit NULL value are interpreted as 8 for multivariate-response fits and as Inf for other fits..

...

further arguments passed to or from other methods.

Details

The random effect terms of the linear predictor are of the form ZLv. In particular, for random-coefficients models (i.e., including random-effect terms such as (z|group) specifying a random-slope component), correlated random effects are represented as b = Lv for some matrix L, and where the elements of v are uncorrelated. In the output of the fit, the Var. column gives the variances of the correlated effects, b=Lv. The Corr. column(s) give their correlation(s). If details is TRUE, estimates and SEs of the (log) variances of the elements of v are reported as for other random effects in the Estimate and cond.SE. columns of the table of lambda coefficients. However, this non-default output is potentially misleading as the elements of v cannot generally be assigned to specific terms (such as intercept and slope) of the random-effect formula, and the representation of b as Lv is not unique.

The condition for abbreviation of formulas, as defined by details$"full.form" is on the number of lines of the unabbreviated output. But the effect, if any, is to truncate individual formulas as function of getOption("width"). For example, when displaying the 10 formulas for a 10-responses multivariate-response fit, the default value of full.form is 8, but 10 lines will still be printed, so this only avoids display of 10 multiline formulas.

Examples

Run this code
## see examples of fitme() or corrHLfit() usage

Run the code above in your browser using DataLab