verbose: Details of the 'verbose' argument of various functions

verboseR Documentation

Details of the verbose argument of various functions

Description

This partially documents the usage of the verbose argument in tow contexts: (1) as an argument of the fitting functions; (2) as an argument of confint.HLfit.

The verbosity of the fitting functions is controlled by the verbose["TRACE"] value. The default is TRACE=FALSE (or 0) which is self-explanatory. TRACE=TRUE (or 1) shows values of outer-estimated parameters (and possibly fixed values of parameters that would be outer-estimated), some cryptic progress bar, and the attained value of the likelihood objective function (see inner-vs-outer for these two types of estimates). See Details for other values.

Tracing the progress of residual-dispersion models is distinctly controlled by verbose["phifit"]: see phi-resid.model.

If the fitted model includes a residual-dispersion model, some tracing output for the latter may be confusingly intermingled with tracing output of the mean-response model. The Details below are valid only for the mean-response model.

confint{., verbose=.} will not affect the verbosity of the fits performed by confint (but will rather affect messages specific to the progress of the confint procedure), unless verbose is a named vector. In particular, verbose["TRACE"] may affect the fit (but this has been implemented only for fit objects inheriting from class pois4mlogit). verbose["confint"] may then be used to control confint. Thus, for pois4mlogit fits,
verbose=FALSE and verbose=c(confint=FALSE) will affect only confint per se, in an equivalent way
verbose=c(TRACE=FALSE) will affect only the fits performed to find the intervals, and
verbose=c(TRACE=FALSE, confint=FALSE) will affect both.
Keep in mind that the verbosity of pois4mlogit fits is also controlled by a progress argument.

Details

0<TRACE<1 only shows the cryptic progress bar.
TRACE=1 was explained above.
TRACE=2 will further show information about the progress of Levenberg-Marquardt-like steps for linear-predictor coefficients.
TRACE=3 will further show information about the progress of distinct Levenberg-Marquardt-like steps random effects given fixed-effect coefficients.
TRACE=4 will further show cryptic information about which matrix computations are requested.
TRACE=5 will further report (through a call to the base trace function) the str(.) of the results of such matrix computations.
TRACE=6 will further pause between iterations of the reweighted least-squares algorithm, allowing a browser session to be called.

(assuming no changes since this was first defined)


spaMM documentation built on Sept. 10, 2026, 1:07 a.m.