Returns a family object for beta-binomial models.
The precision parameter prec of this family is a positive value such that the variance of the beta-distributed latent variable given its mean \(\mu\) is \(\mu(1-\mu)/(1+\)prec). prec is thus the same precision parameter as for the beta family (see beta_resp. The variance of the beta-binomial sample of size \(n\) is response is \(\mu(1-\mu)n(n+\)prec\()/(1+\)prec).
The family described by this object is not a GLM family, so it should not be used as a glm argument unless one additionally uses method="llm.fit" (see Examples).
But it is still characterized by the same concepts as GLMs: a linear predictor, a link function, and the given distribution of residual variation.
A fixed-effect residual-dispersion model can be fitted, using the resid.model argument, which is used to specify the form of the logarithm of the precision parameter (see Examples). Thus the variance of the latent beta-distributed variable becomes \(\mu(1-\mu)/(1+\)exp(<specified linear expression>)).