Returns a family object suitable as a fitme argument for fitting negative-binomial models with variance linearly (affinely) related to the mean \(\mu\): variance=\(\mu+\mu\)/shape. This distribution can be represented as a Poisson-Gamma mixture, where the conditional Poisson mean is \(\mu\) times a Gamma random variable with mean 1 and variance 1/(shape*\(\mu\)) as produced by rgamma(., shape=sh,scale=1/sh) where sh=shape*\(\mu\), meaning that the family shape parameter controls, but differs from, the gamma shape parameter.
The family described by this object is not a GLM family, so it should not be used as a glm argument unless one additionally uses method="llm.fit" (see Examples).
But it is still characterized by the same concepts as GLMs: a linear predictor, a link function, and the given distribution of residual variation.
The zero-truncated variant of this family is also handled, and is never suitable as argument for glm.
A fixed-effect residual-dispersion model can be fitted, using the resid.model argument, which is used to specify the form of the logarithm of the shape parameter. Thus the variance of the response become \(\mu+\mu\)/exp(<specified linear expression>).