# S3 method for HLfit
summary(object, details=FALSE, ...)
# S3 method for HLfitlist
summary(object, ...)
# S3 method for fixedLRT
summary(object, verbose=TRUE, ...)
# S3 method for HLfit
print(x,...)
# S3 method for HLfitlist
print(x,...)
# S3 method for fixedLRT
print(x,...)summary.fixedLRT, whether to print the model fits or not.
(z|group) specifying a random-slope component), correlated random effectsare represented as b = Lv for some matrix L, and where the elements of v are uncorrelated. In the output of the fit, the Var. column gives the
variances of the correlated effects, b=Lv. The Corr. column(s) give their correlation(s). If details is TRUE, estimates and SEs of the (log) variances of the elements of v are reported as for other random effects in the Estimate and cond.SE. columns of the table of lambda coefficients. However, this non-default output is potentially misleading as the elements of v cannot generally be assigned to specific terms (such as intercept and slope) of the random-effect formula, and the representation of b as Lv is not unique.## see examples of corrHLfit usage
Run the code above in your browser using DataLab