One can force spaMM's “outer-optimization” fitting functions to estimate the link exponent by using tweedie(link="fit"), and specyfing init, lower and upper values for the link exponent (using the name Tw_link for their values: see Examples). However this will fail if negative values of \(\eta\) are generated during the fitting process.
Estimates of the residual dispersion parameter \(\phi\) are by default constrained to be > 1e-05 because evaluations of the Tweedie density function are increasingly slow as \(\phi\) approaches 0. Other minimal \(\phi\) value can be set through the lower argument, as usual (or through control.HLfit$min_phi for inner estimation).
When \(p\) is close to 1, the Tweedie density is multimodal; further, when responses are recorded to a limited number of decimal places, the profile likelihood for \(p\) may be bimodal with a spurious maximum at \(p = 1\) (Dunn & Smyth 2005).
From limited numerical experiments, for low \(p\) such as 1.05, computed likelihood profiles with respect to \(\phi\) also often exhibited several maxima. Overall, estimation for low \(p\) will be sensitive to many things.
If the fitting function uses inner-estimation methods to fit \(\phi\) (see inner-vs-outer), it then requires evaluation of a derivative of the Tweedie density, which may be slow or not very accurate, depending on the method used (which can be controlled by the numderiv and optional ... arguments). So the fitting function avoids inner estimation for \(\phi\), when possible. When it is used,
\(\bullet\) examples were found where the inner-estimation iterative algorithm did not converge due to cyclic values of \(\phi\) estimates, for \(p<1.5\). An experimental correction has been implemented to fix this convergence issue;
\(\bullet\) the results are sensitive to the algorithm used to compute the derivative of the conditional likelihood (with the default algorithm appearing better), and maybe more so when both \(p\) and \(\phi\) are small.